@@ -1,9 +1,20 @@
 import pytest
-from dvc.testing.test_api import TestAPI  # noqa, pylint: disable=unused-import
-from dvc.testing.test_remote import (  # noqa, pylint: disable=unused-import
+from dvc.testing.api_tests import (  # noqa, pylint: disable=unused-import
+    TestAPI,
+)
+from dvc.testing.remote_tests import (  # noqa, pylint: disable=unused-import
     TestRemote,
 )
-from dvc.testing.test_workspace import TestImport as _TestImport
+from dvc.testing.workspace_tests import (  # noqa, pylint: disable=unused-import
+    TestAdd as _TestAdd,
+)
+from dvc.testing.workspace_tests import (  # noqa, pylint: disable=unused-import
+    TestGetUrl,
+)
+from dvc.testing.workspace_tests import TestImport as _TestImport
+from dvc.testing.workspace_tests import (  # noqa, pylint: disable=unused-import
+    TestLsUrl,
+)
 
 
 @pytest.fixture
